package com.muyu.mqtt;



import com.alibaba.fastjson.JSON;
import com.muyu.mqtt.dao.MessageData;
import com.muyu.utils.ConversionUtil;
import lombok.extern.log4j.Log4j2;
import org.apache.kafka.clients.admin.NewTopic;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.eclipse.paho.client.mqttv3.IMqttDeliveryToken;
import org.eclipse.paho.client.mqttv3.MqttCallback;
import org.eclipse.paho.client.mqttv3.MqttMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.core.KafkaAdmin;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * 回执消息类 MessageCallbackService
 *
 * @author Yangle
 * Date 2024/6/6 15:08
 */
@Service
@Log4j2
public class MessageCallbackService implements MqttCallback {

    @Autowired
    private KafkaTemplate kafkaTemplate;
    @Autowired
    private KafkaAdmin kafkaAdmin;

    @Override
    public void connectionLost(Throwable cause) {
        System.out.println("connectionLost:"+cause.getMessage());
    }

//    AtomicInteger partitionCounter = new AtomicInteger(-1);

    @Override
    public void messageArrived(String topic, MqttMessage mqttMessage) {
        log.info("topic:{}",topic);
        log.info("Qos:{}",mqttMessage.getQos());
        log.info("message content:{}",new String(mqttMessage.getPayload()));
        String s = new String(mqttMessage.getPayload());
        MessageData main = ConversionUtil.main(s);

//        int numPartitions = 8;
//        NewTopic newTopic = new NewTopic(topic, numPartitions, (short) 1);
//        // 使用轮询计数器来选择分区，并确保它在分区数范围内
//        int partition = partitionCounter.getAndUpdate(prev -> (prev + 1) % numPartitions);

        // 创建ProducerRecord，并指定分区
        ProducerRecord<String, String> producerRecord = new ProducerRecord<>(topic, null, main.getVin(), JSON.toJSONString(main));
        // 发送消息
        kafkaTemplate.send(producerRecord);
    }


    @Override
    public void deliveryComplete(IMqttDeliveryToken token) {
        System.out.println("deliveryComplete---------" + token.isComplete());
    }
}
